<?php

/**
 * @file
 * Drupal Ipsum Drush integration.
 */

/**
 * Implements hook_drush_command().
 */
function drupal_ipsum_drush_command() {
  return array(
    'drupal-ipsum-generate' => array(
      'description' => 'Generate Drupal Ipsum filler text.',
      'aliases' => array('dipsum'),
      'arguments' => array(
        'length' => 'Length of the generated text.',
        'type' => 'Type of the generated text (word, sentence, paragraph)',
        'start' => 'What should the text start with (drupal, lorem, any)',
      ),
      'options' => array(
        'with-markup' => 'Include HTML markup in the generated text',
      ),
      'examples' => array(
        'example[1]' => 'drush dipsum 4 word',
        'example[2]' => 'drush dipsum 1 paragraph drupal',
        'example[3]' => 'drush dipsum 2 sentence any',
      ),
    ),
  );
}

/**
 * Drush command.
 *
 * @param int $length
 * @param string $type
 * @param string $start
 * @see drupal_ipsum_drush_command().
 */
function drush_drupal_ipsum_generate($length = NULL, $type = NULL, $start = NULL) {
  // Convert $type argument to constant.
  if (isset($type)) {
    switch (drupal_strtolower($type)) {
      case 'word':
        $type = 0;
        break;
      case 'sentence':
        $type = 1;
        break;
      case 'paragraph':
        $type = 2;
        break;
      default:
        drush_die(dt('Please enter a valid "type" argument.'));
    }
  }

  // Convert $start argument to constant.
  if (isset($start)) {
    switch (drupal_strtolower($start)) {
      case 'any':
        $start = 0;
        break;
      case 'lorem':
        $start = 1;
        break;
      case 'drupal':
        $start = 2;
        break;
      default:
        drush_die(dt('Please enter a valid "start" argument.'));
    }
  }

  $text = drupal_ipsum_generate($length, $type, $start, FALSE);
  drush_print(dt("\n{$text}\n"));
}

/**
 * Implements hook_drush_help().
 */
function drupal_ipsum_drush_help($section) {
  switch ($section) {
    case 'drush:drupal-ipsum-generate':
      return dt("Generate Drupal Ipsum filler text.");
  }
}