<?php
/**
 * @file
 * Views handlers for Drop Jobs Application.
 */

/**
 * A handler to provide a field with a link to view the job application.
 *
 * @ingroup views_field_handlers
 */
class drop_jobs_application_handler_view extends views_handler_field {

  function construct() {
    parent::construct();

    $this->additional_fields['aid'] = 'aid';
    $this->additional_fields['type'] = 'type';
  }

  function option_definition() {
    $options = parent::option_definition();
    $options['text'] = array('default' => '', 'translatable' => TRUE);
    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text to display'),
      '#default_value' => $this->options['text'],
    );
  }

  function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  function render($values) {
    $text = !empty($this->options['text']) ? $this->options['text'] : t('view');
    $aid = $values->{$this->aliases['aid']};
    return l($text, 'application/' . $aid);
  }

}

/**
 * A handler to provide a field with a link to edit the job application.
 *
 * @ingroup views_field_handlers
 */
class drop_jobs_application_handler_edit extends drop_jobs_application_handler_view {
  function construct() {
    parent::construct();
    $this->additional_fields['type'] = 'type';
  }


  function render($values) {
    $type = $values->{$this->aliases['type']};
    $aid = $values->{$this->aliases['aid']};

    // Creating a dummy application to check access against.
    $dummy = (object) array('aid' => $aid, 'type' => $type);
    if (!drop_jobs_application_access('edit', $dummy)) {
      return;
    }

    $text = !empty($this->options['text']) ? $this->options['text'] : t('edit');
    $aid = $values->{$this->aliases['aid']};

    return l($text, 'application/' . $aid . '/edit');
  }
}

/**
 * A handler to provide a field with a link to delete the job application.
 *
 * @ingroup views_field_handlers
 */
class drop_jobs_application_handler_delete extends drop_jobs_application_handler_view {
  function construct() {
    parent::construct();
    $this->additional_fields['type'] = 'type';
  }


  function render($values) {
    $type = $values->{$this->aliases['type']};
    $aid = $values->{$this->aliases['aid']};

    // Creating a dummy application to check access against.
    $dummy = (object) array('aid' => $aid, 'type' => $type);
    if (!drop_jobs_application_access('delete', $dummy)) {
      return;
    }

    $text = !empty($this->options['text']) ? $this->options['text'] : t('delete');
    $aid = $values->{$this->aliases['aid']};

    return l($text, 'application/' . $aid . '/delete');
  }
}