<?php

/**
 * @file
 * Drop Jobs Hotsite admin settings.
 */

/**
 * Form callback
 * 
 * @see drop_jobs_hotsite_menu().
 */
function drop_jobs_hotsite_settings() {
  $form = array();

  $form['wrapper'] = array(
    '#type' => 'fieldset',
    '#title' => t('Hotsite settings'),
    '#collapsible' => FALSE,
  );

  $form['wrapper']['drop_jobs_hotsite_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Hotsite'),
    '#description' => t('The hotsite is a "pre-registration" period where candidates can register but the rest of the site operates in a restricted manner.'),
    '#default_value' => variable_get_value('drop_jobs_hotsite_enabled'),
  );

  $form['wrapper']['drop_jobs_hotsite_end_auto'] = array(
    '#type' => 'checkbox',
    '#title' => t('End Hotsite Automatically'),
    '#description' => t('Check this option to automatically disable the hotsite on a certain date.'),
    '#default_value' => variable_get_value('drop_jobs_hotsite_end_auto'),
  );

  $form['wrapper']['drop_jobs_hotsite_end_date'] = array(
    '#type' => 'date',
    '#title' => t('Hotsite End Date'),
    '#description' => t('The date when the hotsite will automatically be disabled.'),
    '#default_value' => variable_get_value('drop_jobs_hotsite_end_date'),
    '#size' => 8,
    '#states' => array(
      'invisible' => array(
        'input[name="drop_jobs_hotsite_end_auto"]' => array('checked' => FALSE),
      ),
    ),
  );

  $form['wrapper']['drop_jobs_hotsite_front'] = array(
    '#type' => 'textfield',
    '#title' => t('Hotsite Front Page'),
    '#description' => t('Optionally, specify a relative URL to display as the front page during the hotsite. Leave blank to display the default site front page.'),
    '#default_value' => variable_get_value('drop_jobs_hotsite_front'),
  );

  $form['#submit'][] = 'drop_jobs_hotsite_settings_submit';

  return system_settings_form($form);
}

/**
 * Validate callback
 * 
 * @see drop_jobs_hotsite_settings().
 */
function drop_jobs_hotsite_settings_validate($form, &$form_state) {
  // Validate front page path.
  if (!empty($form_state['values']['drop_jobs_hotsite_front'])) {
    form_set_value($form['wrapper']['drop_jobs_hotsite_front'], drupal_get_normal_path($form_state['values']['drop_jobs_hotsite_front']), $form_state);

    if (!drupal_valid_path($form_state['values']['drop_jobs_hotsite_front'])) {
      form_set_error('drop_jobs_hotsite_front', t("The path '%path' is either invalid or you do not have access to it.", array('%path' => $form_state['values']['drop_jobs_hotsite_front'])));
    }
  }
}

/**
 * Submit callback
 * 
 * @see drop_jobs_hotsite_settings().
 */
function drop_jobs_hotsite_settings_submit($form, &$form_state) {
  if (!empty($form_state['values']['drop_jobs_hotsite_front'])) {
    variable_set_value('site_frontpage', $form_state['values']['drop_jobs_hotsite_front']);
  }
}