<?php

/**
 * @file
 * Drop Jobs Subscription admin settings.
 */

/**
 * Form callback
 *
 * @see drop_jobs_subscription_menu().
 */
function drop_jobs_subscription_settings() {
  $form = array();

  $form['wrapper'] = array(
    '#type' => 'fieldset',
    '#title' => t('Subscription settings'),
    '#collapsible' => FALSE,
  );

  $form['wrapper']['basic'] = array(
    '#type' => 'fieldset',
    '#title' => t('Basic Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['wrapper']['basic']['drop_jobs_subscription_length'] = array(
    '#title' => t('Subscription Length'),
    '#description' => t('How long the subscription lasts, in days.'),
    '#type' => 'textfield',
    '#default_value' => variable_get_value('drop_jobs_subscription_length'),
    '#size' => 2,
  );

  $drop_jobs_subscription_trial = variable_get_value('drop_jobs_subscription_trial');

  $form['wrapper']['basic']['drop_jobs_subscription_trial'] = array(
    '#title' => t('Enable free trials'),
    '#type' => 'checkbox',
    '#description' => t('Enable free trials for subscriptions.'),
    '#default_value' => $drop_jobs_subscription_trial,
  );

  $form['wrapper']['basic']['trial'] = array(
    '#type' => 'fieldset',
    '#title' => t('Trial settings'),
    '#collapsible' => TRUE,
    '#collapsed' => (bool) $drop_jobs_subscription_trial,
    '#states' => array(
      'invisible' => array(
        'input[name="drop_jobs_subscription_trial"]' => array('checked' => FALSE),
      ),
    ),
  );

  $form['wrapper']['basic']['trial']['drop_jobs_subscription_trial_length'] = array(
    '#title' => t('Trial length'),
    '#type' => 'textfield',
    '#description' => t('How long the free trial lasts, in days.'),
    '#default_value' => variable_get_value('drop_jobs_subscription_trial_length'),
    '#size' => 2,
  );

  $options = array();

  foreach (subs_get_types() as $type) {
    $options[$type->id] = $type->label;
  }

  $form['wrapper']['basic']['trial']['drop_jobs_subscription_trial_plans'] = array(
    '#title' => t('Enabled plans'),
    '#type' => 'checkboxes',
    '#description' => t('What plans are enabled for the free trial.'),
    '#options' => $options,
    '#default_value' => variable_get_value('drop_jobs_subscription_trial_plans'),
  );

  $form['wrapper']['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['wrapper']['advanced']['drop_jobs_subscription_show_info_confirm'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show plan information on confirmation page'),
    '#description' => t('If selected, the subscription plan information will be shown above the confirmation form.'),
    '#default_value' => variable_get_value('drop_jobs_subscription_show_info_confirm'),
  );

  $form['wrapper']['advanced']['drop_jobs_subscription_terms'] = array(
    '#type' => 'checkbox',
    '#title' => t('User must agree to Terms and Conditions when subscribing to a plan.'),
    '#default_value' => variable_get_value('drop_jobs_subscription_terms'),
  );

  $form['wrapper']['advanced']['drop_jobs_subscription_terms_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Terms and Conditions page path'),
    '#default_value' => variable_get_value('drop_jobs_subscription_terms_path'),
    '#description' => t('Specify a relative URL'),
    '#states' => array(
      'visible' => array(
        'input[name="drop_jobs_subscription_terms"]' => array('checked' => TRUE),
      ),
    ),
  );

  return system_settings_form($form);
}

/**
 * Validate callback
 *
 * @see drop_jobs_subscription_settings().
 */
function drop_jobs_subscription_settings_validate($form, &$form_state) {
  if (!is_numeric($form_state['values']['drop_jobs_subscription_length'])) {
    form_set_error($form_state['values']['drop_jobs_subscription_length'], t('Subscription length must be numeric.'));
  } else if (!$form_state['values']['drop_jobs_subscription_length'] > 0) {
    form_set_error($form_state['values']['drop_jobs_subscription_length'], t('Subscription length must be greater than 0.'));
  }

  if (!is_numeric($form_state['values']['drop_jobs_subscription_trial_length'])) {
    form_set_error($form_state['values']['drop_jobs_subscription_trial_length'], t('Subscription trial length must be numeric.'));
  } else if (!$form_state['values']['drop_jobs_subscription_trial_length'] > 0) {
    form_set_error($form_state['values']['drop_jobs_subscription_trial_length'], t('Subscription trial length must be greater than 0.'));
  }
}